@@ -1,7 +1,8 @@
 # ABSTRACT: Subroutines for making simple command line scripts
 package CLI::Helpers;
 
-our $VERSION = '1.1';
+our $VERSION = '1.2'; # VERSION
+
 our $_OPTIONS_PARSED;
 
 use strict;
@@ -396,11 +397,17 @@ sub menu {
 
 
 sub pwprompt {
-    my ($prompt) = @_;
+    my ($prompt, %args) = @_;
     $prompt ||= "Password: ";
+    my @more_validate;
+    if (my $validate = $args{validate}){
+        @more_validate = %$validate;
+    }
     return text_input($prompt,
         noecho   => 1,
-        validate => { "password length can't be zero." => sub { defined && length } },
+        validate => { "password length can't be zero." => sub { defined && length },
+                      @more_validate,
+                    },
     );
 }
 
@@ -437,7 +444,7 @@ CLI::Helpers - Subroutines for making simple command line scripts
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -750,7 +757,7 @@ This is free software, licensed under:
 
 =head1 CONTRIBUTORS
 
-=for stopwords Kang-min Liu Mohammad S Anwar
+=for stopwords Kang-min Liu Kevin M. Goess Mohammad S Anwar
 
 =over 4
 
@@ -760,6 +767,10 @@ Kang-min Liu <gugod@gugod.org>
 
 =item *
 
+Kevin M. Goess <kgoess@craigslist.org>
+
+=item *
+
 Mohammad S Anwar <mohammad.anwar@yahoo.com>
 
 =back
